android_packages_modules_Co.../bpf
Repository files (latest commit first)
Filename Latest commit message Latest commit date
Maciej Żenczykowski 116d17a0cf dscpPolicy: verifier optimizations (once more)
Manually tested via x86_64 UML netbpfloader hack on:
  5.15.158-U android/kernel/common/android14-5.15
  c8c7a44800dffe1c3a3840f433ba72f9ab1cdfb0

Combined with previous dscpPolicy verifier optimizer patch load time
goes from 0.151s to 0.061s, but this is on a desktop Android build
capable box.  Decrease of 2.5x will of course be much more noticeable
on slower devices - like Pixel phones, and *even* more noticeable
on low/mid tier devices (including Android Go).

Bug: 361492282
Test: TreeHugger, atest CtsNetTestCases:android.net.cts.DscpPolicyTest
Signed-off-by: Maciej Żenczykowski <maze@google.com>
Change-Id: Ice2bfa0d614d70420c41fb25294bb0425ec273b0
2024-09-06 04:22:58 +00:00
..
headers Merge "bpf_headers: add DEFINE_BPF_RINGBUF macro" into main 2024-09-05 03:20:12 +00:00
loader NetBpfLoad: fix empty log_buf detection logic 2024-09-05 22:00:33 +00:00
netd bpf: git mv netd bpf/netd (plus update visibility for new path) 2024-08-29 22:25:51 +00:00
progs dscpPolicy: verifier optimizations (once more) 2024-09-06 04:22:58 +00:00
syscall_wrappers bpf: git mv staticlibs/native/bpf_syscall_wrappers bpf/syscall_wrappers 2024-08-20 19:51:50 -07:00
tests/mts bpf: test.c - remove XDP program & add placeholder skfilter program 2024-09-06 04:18:02 +00:00